@@ -93,7 +93,7 @@ def getbuilder(
             'rules': rules.dest,
             'logs': pownylogs.dest,
         },
-        command=stoppable('gns $POWNY_MODULE -c {}'.format(configvolume.files('powny.yaml').fullpath)),
+        command=stoppable('gns $POWNY_MODULE -c {}'.format(configvolume.files['powny.yaml'].fullpath)),
     )
     apiimage = SourceImage(
         name='powny-cpython',
